@@ -24,7 +24,7 @@ my $is_linux = ($^O =~ /linux/i) ? 1 : 0;
 my $is_osx = ($^O =~ /darwin/i) ? 1 : 0;
 my $is_bsd = ($^O =~ /bsd/i) ? 1 : 0;
 
-my $def = '-DZMQ_CUSTOM_PLATFORM_HPP -DZMQ_STATIC -D_THREAD_SAFE';
+my $def = '-DZMQ_CUSTOM_PLATFORM_HPP -DZMQ_STATIC -DZMQ_BUILD_DRAFT_API -D_THREAD_SAFE';
 my $lib = '';
 my $otherldflags = '';
 my $inc = '';
@@ -37,6 +37,10 @@ if ($is_gcc)
 	{
 		$ld = 'c++';
 	}
+	elsif ($ld eq 'clang')
+	{
+		$ld = 'clang++';
+	}
 	elsif ($ld =~ /gcc/)
 	{
 		$ld =~ s/gcc/g++/;
@@ -49,11 +53,16 @@ if ($is_gcc)
 		$lib .= ' -lrt';
 	}
 }
-elsif ($is_windows)
+
+if ($is_windows)
 {
-	$def .= ' -D_WINSOCK_DEPRECATED_NO_WARNINGS';
-	$ccflags .= ' -EHsc';
+	$def .= ' -D_WINSOCK_DEPRECATED_NO_WARNINGS -D_CRT_SECURE_NO_WARNINGS';
 	$lib .= ' -lws2_32 -lrpcrt4 -liphlpapi msvcprt.lib';
+
+	if ($is_msvc)
+	{
+		$ccflags .= ' -EHsc';
+	}
 }
 
 # generate the platform.hpp file
@@ -90,11 +99,16 @@ if ($is_linux || $is_osx || $is_bsd)
 {
 	push @opts,
 		'ZMQ_HAVE_TCP_KEEPCNT',
-		'ZMQ_HAVE_TCP_KEEPIDLE',
 		'ZMQ_HAVE_TCP_KEEPINTVL',
 		'ZMQ_HAVE_TCP_KEEPALIVE';
 }
 
+if ($is_linux || $is_bsd)
+{
+	push @opts,
+		'ZMQ_HAVE_TCP_KEEPIDLE',
+}
+
 if (!$is_windows)
 {
 	push @opts,
@@ -239,8 +253,6 @@ my @constants = (qw(
 
 	ZMQ_DONTWAIT
 	ZMQ_SNDMORE
-	ZMQ_MORE
-	ZMQ_SHARED
 
 	ZMQ_POLLIN
 	ZMQ_POLLOUT
@@ -369,6 +381,11 @@ my @socket_options = (qw(
 	ZMQ_USE_FD
 ));
 
+my @message_options = (qw(
+	ZMQ_MORE
+	ZMQ_SHARED
+));
+
 ExtUtils::Constant::WriteConstants
 (
 	NAME         => 'ZMQ::Raw',
@@ -402,6 +419,17 @@ ExtUtils::Constant::WriteConstants
 	C_SUBNAME    => '_socket_option',
 );
 
+ExtUtils::Constant::WriteConstants
+(
+	NAME         => 'ZMQ::Raw::Message',
+	NAMES        => [@message_options],
+	DEFAULT_TYPE => 'IV',
+	C_FILE       => 'const-c-message_options.inc',
+	XS_FILE      => 'const-xs-message_options.inc',
+	XS_SUBNAME   => '_constant',
+	C_SUBNAME    => '_message_option',
+);
+
 unless (eval { ExtUtils::MakeMaker->VERSION(6.56) }) {
 	my $br = delete $WriteMakefileArgs{BUILD_REQUIRES};
 	my $pp = $WriteMakefileArgs{PREREQ_PM};
